.. loky documentation master file, created by
   sphinx-quickstart on Wed Aug  2 16:50:13 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst
